@@ -28,6 +28,15 @@ import urllib
 from .exception import GitProjectException
 from .shell import capture_command
 
+# Python 3.9 things so we don't actually need 3.9.
+
+def _is_relative_to(path, other):
+    try:
+        path.relative_to(other)
+        return True
+    except ValueError:
+        return False
+
 # Git commands
 #
 class Git(object):
@@ -403,6 +412,31 @@ class Git(object):
         """Return whether the configured repository is bare."""
         return self._repo.is_bare
 
+    def get_main_branch(self):
+        """Return the refname of the main branch.  Return none if we cannot determine a
+        unique main branch.
+
+        """
+        main = ''
+        nonmain_branches = []
+        for refname in self.iterrefnames(['refs/heads']):
+            if refname == 'refs/heads/main':
+                main = refname
+            elif refname == 'refs/heads/master':
+                if not main:
+                    main = refname
+            else:
+                nonmain_branches.append(refname)
+
+        if not main:
+            if len(nonmain_branches) == 1:
+                main = nonmain_branches[0]
+
+        if main:
+            return self.branch_name_to_refname(main)
+
+        return None
+
     def workarea_is_clean(self):
         if self.is_bare_repository():
             return True
@@ -426,13 +460,13 @@ class Git(object):
         for name in self._repo.list_worktrees():
             worktree = self._repo.lookup_worktree(name)
             path = Path(worktree.path).resolve()
-            if path == cwd or cwd.is_relative_to(path):
+            if path == cwd or _is_relative_to(cwd, path):
                 return str(path)
 
         # See if we have a GITDIR somewhere along the way.
         gitdir = Path(self._repo.path).resolve()
         while True:
-            if gitdir != cwd and gitdir.is_relative_to(cwd):
+            if gitdir != cwd and _is_relative_to(gitdir, cwd):
                 return cwd
             parent = cwd.parent
             if parent == cwd:
